@@ -7,7 +7,7 @@ use Carp;
 use Woothee::Util qw/update_map update_category update_version update_os/;
 use Woothee::DataSet qw/dataset/;
 
-our $VERSION = "1.0.0";
+our $VERSION = "1.0.1";
 
 sub challenge_msie {
     my ($ua,$result) = @_;
@@ -17,8 +17,8 @@ sub challenge_msie {
     my $version;
     if ($ua =~ m{MSIE ([.0-9]+);}o) {
         $version = $1;
-    } elsif ($ua =~ m{Trident/([.0-9]+);(?: BOIE[0-9]+;[A-Z]+;)? rv:([.0-9]+)}o) {
-        $version = $2;
+    } elsif ($ua =~ m{Trident/([.0-9]+);}o and $ua =~ m{ rv:([.0-9]+)}o) {
+        $version = $1;
     } elsif ($ua =~ m{IEMobile/([.0-9]+);}o) {
         $version = $1;
     } else {
